@@ -157,7 +157,18 @@ DEFAULT_COLUMNS = {
         'id',
         'startDate',
         'endDate',
-        'status'
+        'status',
+        'assistant',
+        'documentFamily'
+    ],
+    'stores': [
+        'orgSlug',
+        'slug',
+        'version',
+        'name',
+        'description',
+        'storeType',
+        'storePurpose'
     ],
     'default': [
         'orgSlug',
